# coding: utf-8

"""
    Buy Feed API

    The Feed API provides the ability to download TSV_GZIP feed files containing eBay items and an hourly snapshot file for a specific category, date, and marketplace.<br /><br />In addition to the API, there is an open-source Feed SDK written in Java that downloads, combines files into a single file when needed, and unzips the entire feed file. It also lets you specify field filters to curate the items in the file.  # noqa: E501

    OpenAPI spec version: v1.2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class FeedTypeConstraint(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'category_ids': 'list[str]',
        'listing_marketplace_constraints': 'list[ListingMarketplaceFeedTypeConstraint]',
        'marketplace_id': 'str'
    }

    attribute_map = {
        'category_ids': 'categoryIds',
        'listing_marketplace_constraints': 'listingMarketplaceConstraints',
        'marketplace_id': 'marketplaceId'
    }

    def __init__(self, category_ids=None, listing_marketplace_constraints=None, marketplace_id=None):  # noqa: E501
        """FeedTypeConstraint - a model defined in Swagger"""  # noqa: E501
        self._category_ids = None
        self._listing_marketplace_constraints = None
        self._marketplace_id = None
        self.discriminator = None
        if category_ids is not None:
            self.category_ids = category_ids
        if listing_marketplace_constraints is not None:
            self.listing_marketplace_constraints = listing_marketplace_constraints
        if marketplace_id is not None:
            self.marketplace_id = marketplace_id

    @property
    def category_ids(self):
        """Gets the category_ids of this FeedTypeConstraint.  # noqa: E501

        An array of the eBay categories the application can access in a feed. See the <a href='https://developer.ebay.com/api-docs/commerce/taxonomy/overview.html'>Taxonomy API</a> for details about obtaining a list eBay L1 categories. The category is expressed as the category's <b>categoryId</b>, not its <b>categoryName</b>; e.g.,  <code>172008</code>, not <code>Gift Cards &amp; Coupons</code>.<br /><br />If no <b>categoryIds</b> are listed, the application can access all categories in the specified marketplace.  # noqa: E501

        :return: The category_ids of this FeedTypeConstraint.  # noqa: E501
        :rtype: list[str]
        """
        return self._category_ids

    @category_ids.setter
    def category_ids(self, category_ids):
        """Sets the category_ids of this FeedTypeConstraint.

        An array of the eBay categories the application can access in a feed. See the <a href='https://developer.ebay.com/api-docs/commerce/taxonomy/overview.html'>Taxonomy API</a> for details about obtaining a list eBay L1 categories. The category is expressed as the category's <b>categoryId</b>, not its <b>categoryName</b>; e.g.,  <code>172008</code>, not <code>Gift Cards &amp; Coupons</code>.<br /><br />If no <b>categoryIds</b> are listed, the application can access all categories in the specified marketplace.  # noqa: E501

        :param category_ids: The category_ids of this FeedTypeConstraint.  # noqa: E501
        :type: list[str]
        """

        self._category_ids = category_ids

    @property
    def listing_marketplace_constraints(self):
        """Gets the listing_marketplace_constraints of this FeedTypeConstraint.  # noqa: E501

        An array of the eBay marketplace and categories in which listings are available for Cross Border Trading (CBT). Listings on the specified marketplace and categories can be shipped to the marketplace specified for the feed type.<br><br><span class=\"tablenote\"><b>Note:</b> This array will only be returned for the <code>CBT_ITEM_ALL_ACTIVE</code> feed type.</span>  # noqa: E501

        :return: The listing_marketplace_constraints of this FeedTypeConstraint.  # noqa: E501
        :rtype: list[ListingMarketplaceFeedTypeConstraint]
        """
        return self._listing_marketplace_constraints

    @listing_marketplace_constraints.setter
    def listing_marketplace_constraints(self, listing_marketplace_constraints):
        """Sets the listing_marketplace_constraints of this FeedTypeConstraint.

        An array of the eBay marketplace and categories in which listings are available for Cross Border Trading (CBT). Listings on the specified marketplace and categories can be shipped to the marketplace specified for the feed type.<br><br><span class=\"tablenote\"><b>Note:</b> This array will only be returned for the <code>CBT_ITEM_ALL_ACTIVE</code> feed type.</span>  # noqa: E501

        :param listing_marketplace_constraints: The listing_marketplace_constraints of this FeedTypeConstraint.  # noqa: E501
        :type: list[ListingMarketplaceFeedTypeConstraint]
        """

        self._listing_marketplace_constraints = listing_marketplace_constraints

    @property
    def marketplace_id(self):
        """Gets the marketplace_id of this FeedTypeConstraint.  # noqa: E501

        This enum value indicates an eBay marketplace for which the application can access feed files for the corresponding feed type<br/><br/><b>Example:</b> <code>EBAY_US</code> for the U.S. or <code>EBAY_DE</code> for Germany. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/buy/feed/types/bas:MarketplaceIdEnum'>eBay API documentation</a>  # noqa: E501

        :return: The marketplace_id of this FeedTypeConstraint.  # noqa: E501
        :rtype: str
        """
        return self._marketplace_id

    @marketplace_id.setter
    def marketplace_id(self, marketplace_id):
        """Sets the marketplace_id of this FeedTypeConstraint.

        This enum value indicates an eBay marketplace for which the application can access feed files for the corresponding feed type<br/><br/><b>Example:</b> <code>EBAY_US</code> for the U.S. or <code>EBAY_DE</code> for Germany. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/buy/feed/types/bas:MarketplaceIdEnum'>eBay API documentation</a>  # noqa: E501

        :param marketplace_id: The marketplace_id of this FeedTypeConstraint.  # noqa: E501
        :type: str
        """

        self._marketplace_id = marketplace_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FeedTypeConstraint, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeedTypeConstraint):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Vero Public API's

    The VeRO API has methods that allow owners of an intellectual property to report eBay listings that infringe on their intellectual property rights. It contains methods to report a listing, retrieve supported VeRO reason codes, and retrieve the status of submitted and items.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class VeroReportItemsRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'report_items': 'list[ReportItemDetails]'
    }

    attribute_map = {
        'report_items': 'reportItems'
    }

    def __init__(self, report_items=None):  # noqa: E501
        """VeroReportItemsRequest - a model defined in Swagger"""  # noqa: E501
        self._report_items = None
        self.discriminator = None
        if report_items is not None:
            self.report_items = report_items

    @property
    def report_items(self):
        """Gets the report_items of this VeroReportItemsRequest.  # noqa: E501

        This array is used to report one or more eBay items that are allegedly violating the product owner's copyright, trademark, or intellectual property rights.<br><br>The <b>itemId</b> and <b>veroReasonCodeId</b> fields are required for each reported violation.<br><br><span class=\"tablenote\"><b>Note:</b> You can report the same item more than once if a different reason code is used each time.</span>  # noqa: E501

        :return: The report_items of this VeroReportItemsRequest.  # noqa: E501
        :rtype: list[ReportItemDetails]
        """
        return self._report_items

    @report_items.setter
    def report_items(self, report_items):
        """Sets the report_items of this VeroReportItemsRequest.

        This array is used to report one or more eBay items that are allegedly violating the product owner's copyright, trademark, or intellectual property rights.<br><br>The <b>itemId</b> and <b>veroReasonCodeId</b> fields are required for each reported violation.<br><br><span class=\"tablenote\"><b>Note:</b> You can report the same item more than once if a different reason code is used each time.</span>  # noqa: E501

        :param report_items: The report_items of this VeroReportItemsRequest.  # noqa: E501
        :type: list[ReportItemDetails]
        """

        self._report_items = report_items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(VeroReportItemsRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VeroReportItemsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Translation API

    This API allows 3rd party developers to translate item titles.  # noqa: E501

    OpenAPI spec version: v1_beta.1.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from ...commerce_translation.api_client import ApiClient


class LanguageApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def translate(self, body, content_type, **kwargs):  # noqa: E501
        """translate  # noqa: E501

        This method translates listing title and listing description text from one language into another. For a full list of supported language translations, see the table in the <a href=\"/api-docs/commerce/translation/overview.html\">API Overview</a> page.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translate(body, content_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TranslateRequest body: (required)
        :param str content_type: This header indicates the format of the request body provided by the client. Its value should be set to <b>application/json</b>. <br><br> For more information, refer to <a href=\"/api-docs/static/rest-request-components.html#HTTP\" target=\"_blank \">HTTP request headers</a>. (required)
        :return: TranslateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.translate_with_http_info(body, content_type, **kwargs)  # noqa: E501
        else:
            (data) = self.translate_with_http_info(body, content_type, **kwargs)  # noqa: E501
            return data

    def translate_with_http_info(self, body, content_type, **kwargs):  # noqa: E501
        """translate  # noqa: E501

        This method translates listing title and listing description text from one language into another. For a full list of supported language translations, see the table in the <a href=\"/api-docs/commerce/translation/overview.html\">API Overview</a> page.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translate_with_http_info(body, content_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TranslateRequest body: (required)
        :param str content_type: This header indicates the format of the request body provided by the client. Its value should be set to <b>application/json</b>. <br><br> For more information, refer to <a href=\"/api-docs/static/rest-request-components.html#HTTP\" target=\"_blank \">HTTP request headers</a>. (required)
        :return: TranslateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'content_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method translate" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `translate`")  # noqa: E501
        # verify the required parameter 'content_type' is set
        if ('content_type' not in params or
                params['content_type'] is None):
            raise ValueError("Missing the required parameter `content_type` when calling `translate`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'content_type' in params:
            header_params['Content-Type'] = params['content_type']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_auth']  # noqa: E501

        return self.api_client.call_api(
            '/translate', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TranslateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    EDIS public shipping API

    <div class=\"msgbox_important\"><p class=\"msgbox_importantInDiv\" data-mc-autonum=\"&lt;b&gt;&lt;span style=&quot;color: #dd1e31;&quot; class=&quot;mcFormatColor&quot;&gt;Important! &lt;/span&gt;&lt;/b&gt;\"><span class=\"autonumber\"><span><b><span style=\"color: #dd1e31;\" class=\"mcFormatColor\">Important!</span></b></span></span> This method is only available for Greater-China based sellers with an active eDIS account.</p></div><br>This API allows 3rd party developers in the Greater-China area to process package shipping details.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SkuRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'elec_qualification_id': 'str',
        'fdc_skus': 'list[FDCSkuRequest]',
        'height': 'float',
        'is_li_battery': 'bool',
        'length': 'float',
        'li_battery_type': 'str',
        'name_en': 'str',
        'name_zh': 'str',
        'origin': 'str',
        'price': 'Amount',
        'remark': 'str',
        'sku_number': 'str',
        'tariff_code': 'str',
        'weight': 'float',
        'width': 'float'
    }

    attribute_map = {
        'elec_qualification_id': 'elecQualificationId',
        'fdc_skus': 'fdcSkus',
        'height': 'height',
        'is_li_battery': 'isLiBattery',
        'length': 'length',
        'li_battery_type': 'liBatteryType',
        'name_en': 'nameEn',
        'name_zh': 'nameZh',
        'origin': 'origin',
        'price': 'price',
        'remark': 'remark',
        'sku_number': 'skuNumber',
        'tariff_code': 'tariffCode',
        'weight': 'weight',
        'width': 'width'
    }

    def __init__(self, elec_qualification_id=None, fdc_skus=None, height=None, is_li_battery=None, length=None, li_battery_type=None, name_en=None, name_zh=None, origin=None, price=None, remark=None, sku_number=None, tariff_code=None, weight=None, width=None):  # noqa: E501
        """SkuRequest - a model defined in Swagger"""  # noqa: E501
        self._elec_qualification_id = None
        self._fdc_skus = None
        self._height = None
        self._is_li_battery = None
        self._length = None
        self._li_battery_type = None
        self._name_en = None
        self._name_zh = None
        self._origin = None
        self._price = None
        self._remark = None
        self._sku_number = None
        self._tariff_code = None
        self._weight = None
        self._width = None
        self.discriminator = None
        if elec_qualification_id is not None:
            self.elec_qualification_id = elec_qualification_id
        if fdc_skus is not None:
            self.fdc_skus = fdc_skus
        if height is not None:
            self.height = height
        if is_li_battery is not None:
            self.is_li_battery = is_li_battery
        if length is not None:
            self.length = length
        if li_battery_type is not None:
            self.li_battery_type = li_battery_type
        if name_en is not None:
            self.name_en = name_en
        if name_zh is not None:
            self.name_zh = name_zh
        if origin is not None:
            self.origin = origin
        if price is not None:
            self.price = price
        if remark is not None:
            self.remark = remark
        if sku_number is not None:
            self.sku_number = sku_number
        if tariff_code is not None:
            self.tariff_code = tariff_code
        if weight is not None:
            self.weight = weight
        if width is not None:
            self.width = width

    @property
    def elec_qualification_id(self):
        """Gets the elec_qualification_id of this SkuRequest.  # noqa: E501

        The unique identifier of the battery's electric qualification, which indicates that the battery has a certificate of approval for global shipping.<br><br>This value is returned in the <a href=\"/api-docs/sell/edelivery_international_shipping/resources/battery_qualifications/methods/getBatteryQualifications\" target=\"_blank\">getBatteryQualifications</a> method.  # noqa: E501

        :return: The elec_qualification_id of this SkuRequest.  # noqa: E501
        :rtype: str
        """
        return self._elec_qualification_id

    @elec_qualification_id.setter
    def elec_qualification_id(self, elec_qualification_id):
        """Sets the elec_qualification_id of this SkuRequest.

        The unique identifier of the battery's electric qualification, which indicates that the battery has a certificate of approval for global shipping.<br><br>This value is returned in the <a href=\"/api-docs/sell/edelivery_international_shipping/resources/battery_qualifications/methods/getBatteryQualifications\" target=\"_blank\">getBatteryQualifications</a> method.  # noqa: E501

        :param elec_qualification_id: The elec_qualification_id of this SkuRequest.  # noqa: E501
        :type: str
        """

        self._elec_qualification_id = elec_qualification_id

    @property
    def fdc_skus(self):
        """Gets the fdc_skus of this SkuRequest.  # noqa: E501

        This array lists the FDC SKUs associated with the item. An FDC SKU is the SKU label in a forward deployment center.<div class=\"msgbox_important\"><p class=\"msgbox_importantInDiv\" data-mc-autonum=\"&lt;b&gt;&lt;span style=&quot;color: #dd1e31;&quot; class=&quot;mcFormatColor&quot;&gt;Important! &lt;/span&gt;&lt;/b&gt;\"><span class=\"autonumber\"><span><b><span style=\"color: #dd1e31;\" class=\"mcFormatColor\">Important!</span></b></span></span> Please contact customer service before using these fields.</p></div>  # noqa: E501

        :return: The fdc_skus of this SkuRequest.  # noqa: E501
        :rtype: list[FDCSkuRequest]
        """
        return self._fdc_skus

    @fdc_skus.setter
    def fdc_skus(self, fdc_skus):
        """Sets the fdc_skus of this SkuRequest.

        This array lists the FDC SKUs associated with the item. An FDC SKU is the SKU label in a forward deployment center.<div class=\"msgbox_important\"><p class=\"msgbox_importantInDiv\" data-mc-autonum=\"&lt;b&gt;&lt;span style=&quot;color: #dd1e31;&quot; class=&quot;mcFormatColor&quot;&gt;Important! &lt;/span&gt;&lt;/b&gt;\"><span class=\"autonumber\"><span><b><span style=\"color: #dd1e31;\" class=\"mcFormatColor\">Important!</span></b></span></span> Please contact customer service before using these fields.</p></div>  # noqa: E501

        :param fdc_skus: The fdc_skus of this SkuRequest.  # noqa: E501
        :type: list[FDCSkuRequest]
        """

        self._fdc_skus = fdc_skus

    @property
    def height(self):
        """Gets the height of this SkuRequest.  # noqa: E501

        The height of the item in centimeters.  # noqa: E501

        :return: The height of this SkuRequest.  # noqa: E501
        :rtype: float
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this SkuRequest.

        The height of the item in centimeters.  # noqa: E501

        :param height: The height of this SkuRequest.  # noqa: E501
        :type: float
        """

        self._height = height

    @property
    def is_li_battery(self):
        """Gets the is_li_battery of this SkuRequest.  # noqa: E501

        This boolean indicates if the item contains a battery.  # noqa: E501

        :return: The is_li_battery of this SkuRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_li_battery

    @is_li_battery.setter
    def is_li_battery(self, is_li_battery):
        """Sets the is_li_battery of this SkuRequest.

        This boolean indicates if the item contains a battery.  # noqa: E501

        :param is_li_battery: The is_li_battery of this SkuRequest.  # noqa: E501
        :type: bool
        """

        self._is_li_battery = is_li_battery

    @property
    def length(self):
        """Gets the length of this SkuRequest.  # noqa: E501

        The length of the item in centimeters.  # noqa: E501

        :return: The length of this SkuRequest.  # noqa: E501
        :rtype: float
        """
        return self._length

    @length.setter
    def length(self, length):
        """Sets the length of this SkuRequest.

        The length of the item in centimeters.  # noqa: E501

        :param length: The length of this SkuRequest.  # noqa: E501
        :type: float
        """

        self._length = length

    @property
    def li_battery_type(self):
        """Gets the li_battery_type of this SkuRequest.  # noqa: E501

        If the item contains a battery, this field indicates the type of battery the item contains. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/edelivery_international_shipping/types/api:LiBatteryTypeEnum'>eBay API documentation</a>  # noqa: E501

        :return: The li_battery_type of this SkuRequest.  # noqa: E501
        :rtype: str
        """
        return self._li_battery_type

    @li_battery_type.setter
    def li_battery_type(self, li_battery_type):
        """Sets the li_battery_type of this SkuRequest.

        If the item contains a battery, this field indicates the type of battery the item contains. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/edelivery_international_shipping/types/api:LiBatteryTypeEnum'>eBay API documentation</a>  # noqa: E501

        :param li_battery_type: The li_battery_type of this SkuRequest.  # noqa: E501
        :type: str
        """

        self._li_battery_type = li_battery_type

    @property
    def name_en(self):
        """Gets the name_en of this SkuRequest.  # noqa: E501

        The English name of the item.  # noqa: E501

        :return: The name_en of this SkuRequest.  # noqa: E501
        :rtype: str
        """
        return self._name_en

    @name_en.setter
    def name_en(self, name_en):
        """Sets the name_en of this SkuRequest.

        The English name of the item.  # noqa: E501

        :param name_en: The name_en of this SkuRequest.  # noqa: E501
        :type: str
        """

        self._name_en = name_en

    @property
    def name_zh(self):
        """Gets the name_zh of this SkuRequest.  # noqa: E501

        The Chinese name of the item.  # noqa: E501

        :return: The name_zh of this SkuRequest.  # noqa: E501
        :rtype: str
        """
        return self._name_zh

    @name_zh.setter
    def name_zh(self, name_zh):
        """Sets the name_zh of this SkuRequest.

        The Chinese name of the item.  # noqa: E501

        :param name_zh: The name_zh of this SkuRequest.  # noqa: E501
        :type: str
        """

        self._name_zh = name_zh

    @property
    def origin(self):
        """Gets the origin of this SkuRequest.  # noqa: E501

        The country of origin of the item.  # noqa: E501

        :return: The origin of this SkuRequest.  # noqa: E501
        :rtype: str
        """
        return self._origin

    @origin.setter
    def origin(self, origin):
        """Sets the origin of this SkuRequest.

        The country of origin of the item.  # noqa: E501

        :param origin: The origin of this SkuRequest.  # noqa: E501
        :type: str
        """

        self._origin = origin

    @property
    def price(self):
        """Gets the price of this SkuRequest.  # noqa: E501


        :return: The price of this SkuRequest.  # noqa: E501
        :rtype: Amount
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this SkuRequest.


        :param price: The price of this SkuRequest.  # noqa: E501
        :type: Amount
        """

        self._price = price

    @property
    def remark(self):
        """Gets the remark of this SkuRequest.  # noqa: E501

        A remark to the seller themselves.  # noqa: E501

        :return: The remark of this SkuRequest.  # noqa: E501
        :rtype: str
        """
        return self._remark

    @remark.setter
    def remark(self, remark):
        """Sets the remark of this SkuRequest.

        A remark to the seller themselves.  # noqa: E501

        :param remark: The remark of this SkuRequest.  # noqa: E501
        :type: str
        """

        self._remark = remark

    @property
    def sku_number(self):
        """Gets the sku_number of this SkuRequest.  # noqa: E501

        The stock keeping unit (SKU) identifier of the item.  # noqa: E501

        :return: The sku_number of this SkuRequest.  # noqa: E501
        :rtype: str
        """
        return self._sku_number

    @sku_number.setter
    def sku_number(self, sku_number):
        """Sets the sku_number of this SkuRequest.

        The stock keeping unit (SKU) identifier of the item.  # noqa: E501

        :param sku_number: The sku_number of this SkuRequest.  # noqa: E501
        :type: str
        """

        self._sku_number = sku_number

    @property
    def tariff_code(self):
        """Gets the tariff_code of this SkuRequest.  # noqa: E501

        The Harmonized System code for custom declaration. This value declares the category of the item..  # noqa: E501

        :return: The tariff_code of this SkuRequest.  # noqa: E501
        :rtype: str
        """
        return self._tariff_code

    @tariff_code.setter
    def tariff_code(self, tariff_code):
        """Sets the tariff_code of this SkuRequest.

        The Harmonized System code for custom declaration. This value declares the category of the item..  # noqa: E501

        :param tariff_code: The tariff_code of this SkuRequest.  # noqa: E501
        :type: str
        """

        self._tariff_code = tariff_code

    @property
    def weight(self):
        """Gets the weight of this SkuRequest.  # noqa: E501

        The weight of the item in grams.  # noqa: E501

        :return: The weight of this SkuRequest.  # noqa: E501
        :rtype: float
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """Sets the weight of this SkuRequest.

        The weight of the item in grams.  # noqa: E501

        :param weight: The weight of this SkuRequest.  # noqa: E501
        :type: float
        """

        self._weight = weight

    @property
    def width(self):
        """Gets the width of this SkuRequest.  # noqa: E501

        The width of the item in centimeters.  # noqa: E501

        :return: The width of this SkuRequest.  # noqa: E501
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this SkuRequest.

        The width of the item in centimeters.  # noqa: E501

        :param width: The width of this SkuRequest.  # noqa: E501
        :type: float
        """

        self._width = width

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SkuRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SkuRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Vero Public API's

    The VeRO API has methods that allow owners of an intellectual property to report eBay listings that infringe on their intellectual property rights. It contains methods to report a listing, retrieve supported VeRO reason codes, and retrieve the status of submitted and items.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class VeroReasonCode(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'marketplace_id': 'str',
        'reason_code_details': 'list[ReasonCodeDetailType]'
    }

    attribute_map = {
        'marketplace_id': 'marketplaceId',
        'reason_code_details': 'reasonCodeDetails'
    }

    def __init__(self, marketplace_id=None, reason_code_details=None):  # noqa: E501
        """VeroReasonCode - a model defined in Swagger"""  # noqa: E501
        self._marketplace_id = None
        self._reason_code_details = None
        self.discriminator = None
        if marketplace_id is not None:
            self.marketplace_id = marketplace_id
        if reason_code_details is not None:
            self.reason_code_details = reason_code_details

    @property
    def marketplace_id(self):
        """Gets the marketplace_id of this VeroReasonCode.  # noqa: E501

        The eBay site for which reason code details are returned. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/commerce/vero/types/br:MarketplaceIdEnum'>eBay API documentation</a>  # noqa: E501

        :return: The marketplace_id of this VeroReasonCode.  # noqa: E501
        :rtype: str
        """
        return self._marketplace_id

    @marketplace_id.setter
    def marketplace_id(self, marketplace_id):
        """Sets the marketplace_id of this VeroReasonCode.

        The eBay site for which reason code details are returned. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/commerce/vero/types/br:MarketplaceIdEnum'>eBay API documentation</a>  # noqa: E501

        :param marketplace_id: The marketplace_id of this VeroReasonCode.  # noqa: E501
        :type: str
        """

        self._marketplace_id = marketplace_id

    @property
    def reason_code_details(self):
        """Gets the reason_code_details of this VeroReasonCode.  # noqa: E501

        This container includes both brief and detailed text descriptions for the VeRO program intellectual property right infringement reason, as well as the ID for the reason code.  # noqa: E501

        :return: The reason_code_details of this VeroReasonCode.  # noqa: E501
        :rtype: list[ReasonCodeDetailType]
        """
        return self._reason_code_details

    @reason_code_details.setter
    def reason_code_details(self, reason_code_details):
        """Sets the reason_code_details of this VeroReasonCode.

        This container includes both brief and detailed text descriptions for the VeRO program intellectual property right infringement reason, as well as the ID for the reason code.  # noqa: E501

        :param reason_code_details: The reason_code_details of this VeroReasonCode.  # noqa: E501
        :type: list[ReasonCodeDetailType]
        """

        self._reason_code_details = reason_code_details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(VeroReasonCode, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VeroReasonCode):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Metadata API

    The Metadata API has operations that retrieve configuration details pertaining to the different eBay marketplaces. In addition to marketplace information, the API also has operations that get information that helps sellers list items on eBay.  # noqa: E501

    OpenAPI spec version: v1.11.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Amount(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'currency': 'str',
        'value': 'str'
    }

    attribute_map = {
        'currency': 'currency',
        'value': 'value'
    }

    def __init__(self, currency=None, value=None):  # noqa: E501
        """Amount - a model defined in Swagger"""  # noqa: E501
        self._currency = None
        self._value = None
        self.discriminator = None
        if currency is not None:
            self.currency = currency
        if value is not None:
            self.value = value

    @property
    def currency(self):
        """Gets the currency of this Amount.  # noqa: E501

        The three-letter <a href=\"https://www.iso.org/iso-4217-currency-codes.html \" target=\"_blank\">ISO 4217</a> code representing the currency of the amount in the <b> value</b> field.  <br /><br /><b>Restriction: </b> Only the currency of the marketplace is supported. For example, on the US marketplace the only currency supported is USD. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/bas:CurrencyCodeEnum'>eBay API documentation</a>  # noqa: E501

        :return: The currency of this Amount.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Amount.

        The three-letter <a href=\"https://www.iso.org/iso-4217-currency-codes.html \" target=\"_blank\">ISO 4217</a> code representing the currency of the amount in the <b> value</b> field.  <br /><br /><b>Restriction: </b> Only the currency of the marketplace is supported. For example, on the US marketplace the only currency supported is USD. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/bas:CurrencyCodeEnum'>eBay API documentation</a>  # noqa: E501

        :param currency: The currency of this Amount.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def value(self):
        """Gets the value of this Amount.  # noqa: E501

        The monetary amount, in the currency specified by the <b>currency</b> field.  # noqa: E501

        :return: The value of this Amount.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this Amount.

        The monetary amount, in the currency specified by the <b>currency</b> field.  # noqa: E501

        :param value: The value of this Amount.  # noqa: E501
        :type: str
        """

        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Amount, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Amount):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    EDIS public shipping API

    <div class=\"msgbox_important\"><p class=\"msgbox_importantInDiv\" data-mc-autonum=\"&lt;b&gt;&lt;span style=&quot;color: #dd1e31;&quot; class=&quot;mcFormatColor&quot;&gt;Important! &lt;/span&gt;&lt;/b&gt;\"><span class=\"autonumber\"><span><b><span style=\"color: #dd1e31;\" class=\"mcFormatColor\">Important!</span></b></span></span> This method is only available for Greater-China based sellers with an active eDIS account.</p></div><br>This API allows 3rd party developers in the Greater-China area to process package shipping details.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AddComplaintRequestData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'affected_packages': 'list[str]',
        'complaint_date': 'str',
        'complaint_reason': 'str',
        'complaint_type': 'str',
        'preference_id': 'int',
        'remark': 'str'
    }

    attribute_map = {
        'affected_packages': 'affectedPackages',
        'complaint_date': 'complaintDate',
        'complaint_reason': 'complaintReason',
        'complaint_type': 'complaintType',
        'preference_id': 'preferenceId',
        'remark': 'remark'
    }

    def __init__(self, affected_packages=None, complaint_date=None, complaint_reason=None, complaint_type=None, preference_id=None, remark=None):  # noqa: E501
        """AddComplaintRequestData - a model defined in Swagger"""  # noqa: E501
        self._affected_packages = None
        self._complaint_date = None
        self._complaint_reason = None
        self._complaint_type = None
        self._preference_id = None
        self._remark = None
        self.discriminator = None
        if affected_packages is not None:
            self.affected_packages = affected_packages
        if complaint_date is not None:
            self.complaint_date = complaint_date
        if complaint_reason is not None:
            self.complaint_reason = complaint_reason
        if complaint_type is not None:
            self.complaint_type = complaint_type
        if preference_id is not None:
            self.preference_id = preference_id
        if remark is not None:
            self.remark = remark

    @property
    def affected_packages(self):
        """Gets the affected_packages of this AddComplaintRequestData.  # noqa: E501

        This array specifies a list of packages, specified by their <b>packageId</b>, affected by the issue causing the complaint.<br><br>Package ID values are returned when creating a package through the <a href=\"/api-docs/sell/edelivery_international_shipping/resources/package/methods/createPackage\" target=\"_blank\">createPackage</a> method<br><br>This array is required if the complaint being filed is for a missing package.  # noqa: E501

        :return: The affected_packages of this AddComplaintRequestData.  # noqa: E501
        :rtype: list[str]
        """
        return self._affected_packages

    @affected_packages.setter
    def affected_packages(self, affected_packages):
        """Sets the affected_packages of this AddComplaintRequestData.

        This array specifies a list of packages, specified by their <b>packageId</b>, affected by the issue causing the complaint.<br><br>Package ID values are returned when creating a package through the <a href=\"/api-docs/sell/edelivery_international_shipping/resources/package/methods/createPackage\" target=\"_blank\">createPackage</a> method<br><br>This array is required if the complaint being filed is for a missing package.  # noqa: E501

        :param affected_packages: The affected_packages of this AddComplaintRequestData.  # noqa: E501
        :type: list[str]
        """

        self._affected_packages = affected_packages

    @property
    def complaint_date(self):
        """Gets the complaint_date of this AddComplaintRequestData.  # noqa: E501

        The date in which the issue associated with the complaint occurred.<br><br><b>Format:</b> <code>YYYY-MM-DDTHH:MM:SS.SSSZ</code>   # noqa: E501

        :return: The complaint_date of this AddComplaintRequestData.  # noqa: E501
        :rtype: str
        """
        return self._complaint_date

    @complaint_date.setter
    def complaint_date(self, complaint_date):
        """Sets the complaint_date of this AddComplaintRequestData.

        The date in which the issue associated with the complaint occurred.<br><br><b>Format:</b> <code>YYYY-MM-DDTHH:MM:SS.SSSZ</code>   # noqa: E501

        :param complaint_date: The complaint_date of this AddComplaintRequestData.  # noqa: E501
        :type: str
        """

        self._complaint_date = complaint_date

    @property
    def complaint_reason(self):
        """Gets the complaint_reason of this AddComplaintRequestData.  # noqa: E501

        This string specifies the reason the complaint was filed.<br><br><b>Max length</b>: 200 characters  # noqa: E501

        :return: The complaint_reason of this AddComplaintRequestData.  # noqa: E501
        :rtype: str
        """
        return self._complaint_reason

    @complaint_reason.setter
    def complaint_reason(self, complaint_reason):
        """Sets the complaint_reason of this AddComplaintRequestData.

        This string specifies the reason the complaint was filed.<br><br><b>Max length</b>: 200 characters  # noqa: E501

        :param complaint_reason: The complaint_reason of this AddComplaintRequestData.  # noqa: E501
        :type: str
        """

        self._complaint_reason = complaint_reason

    @property
    def complaint_type(self):
        """Gets the complaint_type of this AddComplaintRequestData.  # noqa: E501

        The type of complaint being filed.<br><br><b>Valid values</b>:<ul><li><code>ABNORMAL_COLLECTION_COMPLAINT</code></li><li><code>LOST_PACKAGE_COMPLAINT</code></li></ul> For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/edelivery_international_shipping/types/api:ComplaintTypeEnum'>eBay API documentation</a>  # noqa: E501

        :return: The complaint_type of this AddComplaintRequestData.  # noqa: E501
        :rtype: str
        """
        return self._complaint_type

    @complaint_type.setter
    def complaint_type(self, complaint_type):
        """Sets the complaint_type of this AddComplaintRequestData.

        The type of complaint being filed.<br><br><b>Valid values</b>:<ul><li><code>ABNORMAL_COLLECTION_COMPLAINT</code></li><li><code>LOST_PACKAGE_COMPLAINT</code></li></ul> For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/edelivery_international_shipping/types/api:ComplaintTypeEnum'>eBay API documentation</a>  # noqa: E501

        :param complaint_type: The complaint_type of this AddComplaintRequestData.  # noqa: E501
        :type: str
        """

        self._complaint_type = complaint_type

    @property
    def preference_id(self):
        """Gets the preference_id of this AddComplaintRequestData.  # noqa: E501

        The unique identifier of the address associated with the complaint.<br><br>This field is required if the complain being filed is associated with a specific address.  # noqa: E501

        :return: The preference_id of this AddComplaintRequestData.  # noqa: E501
        :rtype: int
        """
        return self._preference_id

    @preference_id.setter
    def preference_id(self, preference_id):
        """Sets the preference_id of this AddComplaintRequestData.

        The unique identifier of the address associated with the complaint.<br><br>This field is required if the complain being filed is associated with a specific address.  # noqa: E501

        :param preference_id: The preference_id of this AddComplaintRequestData.  # noqa: E501
        :type: int
        """

        self._preference_id = preference_id

    @property
    def remark(self):
        """Gets the remark of this AddComplaintRequestData.  # noqa: E501

        A remark to the seller themselves.  # noqa: E501

        :return: The remark of this AddComplaintRequestData.  # noqa: E501
        :rtype: str
        """
        return self._remark

    @remark.setter
    def remark(self, remark):
        """Sets the remark of this AddComplaintRequestData.

        A remark to the seller themselves.  # noqa: E501

        :param remark: The remark of this AddComplaintRequestData.  # noqa: E501
        :type: str
        """

        self._remark = remark

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddComplaintRequestData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddComplaintRequestData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Metadata API

    The Metadata API has operations that retrieve configuration details pertaining to the different eBay marketplaces. In addition to marketplace information, the API also has operations that get information that helps sellers list items on eBay.  # noqa: E501

    OpenAPI spec version: v1.11.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MultiCompatibilityPropertyValuesResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'compatibilities': 'list[Compatibility]',
        'metadata_version': 'str'
    }

    attribute_map = {
        'compatibilities': 'compatibilities',
        'metadata_version': 'metadataVersion'
    }

    def __init__(self, compatibilities=None, metadata_version=None):  # noqa: E501
        """MultiCompatibilityPropertyValuesResponse - a model defined in Swagger"""  # noqa: E501
        self._compatibilities = None
        self._metadata_version = None
        self.discriminator = None
        if compatibilities is not None:
            self.compatibilities = compatibilities
        if metadata_version is not None:
            self.metadata_version = metadata_version

    @property
    def compatibilities(self):
        """Gets the compatibilities of this MultiCompatibilityPropertyValuesResponse.  # noqa: E501

        This container defines the compatibility details associated with the specified property name value(s).  # noqa: E501

        :return: The compatibilities of this MultiCompatibilityPropertyValuesResponse.  # noqa: E501
        :rtype: list[Compatibility]
        """
        return self._compatibilities

    @compatibilities.setter
    def compatibilities(self, compatibilities):
        """Sets the compatibilities of this MultiCompatibilityPropertyValuesResponse.

        This container defines the compatibility details associated with the specified property name value(s).  # noqa: E501

        :param compatibilities: The compatibilities of this MultiCompatibilityPropertyValuesResponse.  # noqa: E501
        :type: list[Compatibility]
        """

        self._compatibilities = compatibilities

    @property
    def metadata_version(self):
        """Gets the metadata_version of this MultiCompatibilityPropertyValuesResponse.  # noqa: E501

        The version number of the metadata. This version is upticked whenever there are compatibility name changes for the specified marketplace.  # noqa: E501

        :return: The metadata_version of this MultiCompatibilityPropertyValuesResponse.  # noqa: E501
        :rtype: str
        """
        return self._metadata_version

    @metadata_version.setter
    def metadata_version(self, metadata_version):
        """Sets the metadata_version of this MultiCompatibilityPropertyValuesResponse.

        The version number of the metadata. This version is upticked whenever there are compatibility name changes for the specified marketplace.  # noqa: E501

        :param metadata_version: The metadata_version of this MultiCompatibilityPropertyValuesResponse.  # noqa: E501
        :type: str
        """

        self._metadata_version = metadata_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MultiCompatibilityPropertyValuesResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MultiCompatibilityPropertyValuesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Media API

    The <b>Media API</b> lets sellers to create, upload, and retrieve files, including:<ul><li>images</li><li>videos</li><li>documents (for GPSR regulations)</li></ul>  # noqa: E501

    OpenAPI spec version: v1_beta.4.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from ...commerce_media.api_client import ApiClient


class ImageApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_image_from_file(self, content_type, **kwargs):  # noqa: E501
        """create_image_from_file  # noqa: E501

        This method uploads a picture file to eBay Picture Services (EPS) using multipart/form-data. <p>All images must comply with eBay's picture requirements, such as dimension and file size restrictions. For more information, see <a href=\"https://www.ebay.com/help/policies/listing-policies/picture-policy?id=4370\"  target=\"_blank\">Picture policy</a>. The image formats supported are <b>JPG</b>, <b>GIF</b>, <b>PNG</b>, <b>BMP</b>, <b>TIFF</b>, <b>AVIF</b>, <b>HEIC</b>, and <b>WEBP</b>. For more information, see <a href=\"/api-docs/sell/static/inventory/managing-image-media.html#image-requirements\" target=\"_blank\">Image requirements</a>.</p><p><span class=\"tablenote\"><strong>Note:</strong> Animated GIF, and multi-page PNG/TIFF files, are not supported. Any animation effect of supported formats will be lost upon upload.</span></p><p>This call does not have a JSON Request payload but uploads the file as form-data. For example:<br /> <pre> image: &quot;sample_picture.jpg&quot; </pre>See <a href=\"/api-docs/commerce/media/resources/image/methods/createImageFromFile#h2-samples\">Samples</a> for information.</p><p><span class=\"tablenote\"><strong>Note:</strong> You must use a <b>Content-Type</b> header with its value set to 'multipart/form-data'.</span></p><p>When an EPS image is successfully created, the method returns the HTTP Status Code <code>201 Created</code>. The method also returns the getImage URI in the <b>Location</b> response header.</p><div class=\"msgbox_important\"><p class=\"msgbox_importantInDiv\" data-mc-autonum=\"&lt;b&gt;&lt;span style=&quot;color: #dd1e31;&quot; class=&quot;mcFormatColor&quot;&gt;Important! &lt;/span&gt;&lt;/b&gt;\"><span class=\"autonumber\"><span><b><span style=\"color: #dd1e31;\" class=\"mcFormatColor\">Important!</span></b></span></span> Make sure to capture the image ID URI returned in the response <a href=\"/api-docs/commerce/media/resources/image/methods/createImageFromFile#h2-output\">location header</a> provided in the following format:</p><p><code>https://apim.ebay.com/commerce/media/v1_beta/image/<em>{image_id}</em></code> </p><p>You can capture the entire URI, or just save the <code>{image_id}</code> only. Pass the <code>{image_id}</code> as a path parameter in the <b><a href=\"/api-docs/commerce/media/resources/image/methods/getImage\" target=\"_blank\">getImage</a></b> method to return the value needed to associate an image to a listing using the Trading and Inventory APIs.</p></div><p>See <a href=\"/api-docs/sell/static/inventory/managing-image-media.html\" target=\"_blank\">Managing images</a> for additional details.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_image_from_file(content_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str content_type: This header indicates the format of the request body provided by the client. Its value should be set to <b>multipart/form-data</b>. <br><br> For more information, refer to <a href=\"/api-docs/static/rest-request-components.html#HTTP\" target=\"_blank \">HTTP request headers</a>. (required)
        :return: ImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_image_from_file_with_http_info(content_type, **kwargs)  # noqa: E501
        else:
            (data) = self.create_image_from_file_with_http_info(content_type, **kwargs)  # noqa: E501
            return data

    def create_image_from_file_with_http_info(self, content_type, **kwargs):  # noqa: E501
        """create_image_from_file  # noqa: E501

        This method uploads a picture file to eBay Picture Services (EPS) using multipart/form-data. <p>All images must comply with eBay's picture requirements, such as dimension and file size restrictions. For more information, see <a href=\"https://www.ebay.com/help/policies/listing-policies/picture-policy?id=4370\"  target=\"_blank\">Picture policy</a>. The image formats supported are <b>JPG</b>, <b>GIF</b>, <b>PNG</b>, <b>BMP</b>, <b>TIFF</b>, <b>AVIF</b>, <b>HEIC</b>, and <b>WEBP</b>. For more information, see <a href=\"/api-docs/sell/static/inventory/managing-image-media.html#image-requirements\" target=\"_blank\">Image requirements</a>.</p><p><span class=\"tablenote\"><strong>Note:</strong> Animated GIF, and multi-page PNG/TIFF files, are not supported. Any animation effect of supported formats will be lost upon upload.</span></p><p>This call does not have a JSON Request payload but uploads the file as form-data. For example:<br /> <pre> image: &quot;sample_picture.jpg&quot; </pre>See <a href=\"/api-docs/commerce/media/resources/image/methods/createImageFromFile#h2-samples\">Samples</a> for information.</p><p><span class=\"tablenote\"><strong>Note:</strong> You must use a <b>Content-Type</b> header with its value set to 'multipart/form-data'.</span></p><p>When an EPS image is successfully created, the method returns the HTTP Status Code <code>201 Created</code>. The method also returns the getImage URI in the <b>Location</b> response header.</p><div class=\"msgbox_important\"><p class=\"msgbox_importantInDiv\" data-mc-autonum=\"&lt;b&gt;&lt;span style=&quot;color: #dd1e31;&quot; class=&quot;mcFormatColor&quot;&gt;Important! &lt;/span&gt;&lt;/b&gt;\"><span class=\"autonumber\"><span><b><span style=\"color: #dd1e31;\" class=\"mcFormatColor\">Important!</span></b></span></span> Make sure to capture the image ID URI returned in the response <a href=\"/api-docs/commerce/media/resources/image/methods/createImageFromFile#h2-output\">location header</a> provided in the following format:</p><p><code>https://apim.ebay.com/commerce/media/v1_beta/image/<em>{image_id}</em></code> </p><p>You can capture the entire URI, or just save the <code>{image_id}</code> only. Pass the <code>{image_id}</code> as a path parameter in the <b><a href=\"/api-docs/commerce/media/resources/image/methods/getImage\" target=\"_blank\">getImage</a></b> method to return the value needed to associate an image to a listing using the Trading and Inventory APIs.</p></div><p>See <a href=\"/api-docs/sell/static/inventory/managing-image-media.html\" target=\"_blank\">Managing images</a> for additional details.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_image_from_file_with_http_info(content_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str content_type: This header indicates the format of the request body provided by the client. Its value should be set to <b>multipart/form-data</b>. <br><br> For more information, refer to <a href=\"/api-docs/static/rest-request-components.html#HTTP\" target=\"_blank \">HTTP request headers</a>. (required)
        :return: ImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['content_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_image_from_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'content_type' is set
        if ('content_type' not in params or
                params['content_type'] is None):
            raise ValueError("Missing the required parameter `content_type` when calling `create_image_from_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'content_type' in params:
            header_params['Content-Type'] = params['content_type']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_auth']  # noqa: E501

        return self.api_client.call_api(
            '/image/create_image_from_file', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ImageResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_image_from_url(self, body, content_type, **kwargs):  # noqa: E501
        """create_image_from_url  # noqa: E501

        This method uploads a picture to eBay Picture Services (EPS) from the specified URL. Specify the location of the picture on an external web server through the <b>imageUrl</b> field. <p>All images must comply with eBay’s picture requirements, such as dimension and file size restrictions. For more information, see <a href=\"https://www.ebay.com/help/policies/listing-policies/picture-policy?id=4370\" target=\"_blank\">Picture policy</a>. The image formats supported are <b>JPG</b>, <b>GIF</b>, <b>PNG</b>, <b>BMP</b>, <b>TIFF</b>, <b>AVIF</b>, <b>HEIC</b>, and <b>WEBP</b>. In addition, the provided URL must be secured using HTTPS (HTTP is not permitted). For more information, see <a href=\"/api-docs/sell/static/inventory/managing-image-media.html#image-requirements\" target=\"_blank\">Image requirements</a>.</p><p><span class=\"tablenote\"><strong>Note:</strong> Animated GIF, and multi-page PNG/TIFF files, are not supported. Any animation effect of supported formats will be lost upon upload.</span></p><p>When an EPS image is successfully created, the method returns the HTTP Status Code <code>201 Created</code>. The method also returns the getImage URI in the <b>Location</b> response header.</p><div class=\"msgbox_important\"><p class=\"msgbox_importantInDiv\" data-mc-autonum=\"&lt;b&gt;&lt;span style=&quot;color: #dd1e31;&quot; class=&quot;mcFormatColor&quot;&gt;Important! &lt;/span&gt;&lt;/b&gt;\"><span class=\"autonumber\"><span><b><span style=\"color: #dd1e31;\" class=\"mcFormatColor\">Important!</span></b></span></span> Make sure to capture the image ID URI returned in the response <a href=\"/api-docs/commerce/media/resources/image/methods/createImageFromUrl#h2-output\">location header</a> provided in the following format:</p><p><code>https://apim.ebay.com/commerce/media/v1_beta/image/<em>{image_id}</em></code> </p><p>You can capture the entire URI, or just save the <code>{image_id}</code> only. Pass the <code>{image_id}</code> as a path parameter in the <b><a href=\"/api-docs/commerce/media/resources/image/methods/getImage\" target=\"_blank\">getImage</a></b> method to return the value needed to associate an image to a listing using the Trading and Inventory APIs.</p></div><p>See <a href=\"/api-docs/sell/static/inventory/managing-image-media.html\" target=\"_blank\">Managing images</a> for additional details.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_image_from_url(body, content_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateImageFromUrlRequest body: (required)
        :param str content_type: This header indicates the format of the request body provided by the client. Its value should be set to <b>application/json</b>. <br><br> For more information, refer to <a href=\"/api-docs/static/rest-request-components.html#HTTP\" target=\"_blank \">HTTP request headers</a>. (required)
        :return: ImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_image_from_url_with_http_info(body, content_type, **kwargs)  # noqa: E501
        else:
            (data) = self.create_image_from_url_with_http_info(body, content_type, **kwargs)  # noqa: E501
            return data

    def create_image_from_url_with_http_info(self, body, content_type, **kwargs):  # noqa: E501
        """create_image_from_url  # noqa: E501

        This method uploads a picture to eBay Picture Services (EPS) from the specified URL. Specify the location of the picture on an external web server through the <b>imageUrl</b> field. <p>All images must comply with eBay’s picture requirements, such as dimension and file size restrictions. For more information, see <a href=\"https://www.ebay.com/help/policies/listing-policies/picture-policy?id=4370\" target=\"_blank\">Picture policy</a>. The image formats supported are <b>JPG</b>, <b>GIF</b>, <b>PNG</b>, <b>BMP</b>, <b>TIFF</b>, <b>AVIF</b>, <b>HEIC</b>, and <b>WEBP</b>. In addition, the provided URL must be secured using HTTPS (HTTP is not permitted). For more information, see <a href=\"/api-docs/sell/static/inventory/managing-image-media.html#image-requirements\" target=\"_blank\">Image requirements</a>.</p><p><span class=\"tablenote\"><strong>Note:</strong> Animated GIF, and multi-page PNG/TIFF files, are not supported. Any animation effect of supported formats will be lost upon upload.</span></p><p>When an EPS image is successfully created, the method returns the HTTP Status Code <code>201 Created</code>. The method also returns the getImage URI in the <b>Location</b> response header.</p><div class=\"msgbox_important\"><p class=\"msgbox_importantInDiv\" data-mc-autonum=\"&lt;b&gt;&lt;span style=&quot;color: #dd1e31;&quot; class=&quot;mcFormatColor&quot;&gt;Important! &lt;/span&gt;&lt;/b&gt;\"><span class=\"autonumber\"><span><b><span style=\"color: #dd1e31;\" class=\"mcFormatColor\">Important!</span></b></span></span> Make sure to capture the image ID URI returned in the response <a href=\"/api-docs/commerce/media/resources/image/methods/createImageFromUrl#h2-output\">location header</a> provided in the following format:</p><p><code>https://apim.ebay.com/commerce/media/v1_beta/image/<em>{image_id}</em></code> </p><p>You can capture the entire URI, or just save the <code>{image_id}</code> only. Pass the <code>{image_id}</code> as a path parameter in the <b><a href=\"/api-docs/commerce/media/resources/image/methods/getImage\" target=\"_blank\">getImage</a></b> method to return the value needed to associate an image to a listing using the Trading and Inventory APIs.</p></div><p>See <a href=\"/api-docs/sell/static/inventory/managing-image-media.html\" target=\"_blank\">Managing images</a> for additional details.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_image_from_url_with_http_info(body, content_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateImageFromUrlRequest body: (required)
        :param str content_type: This header indicates the format of the request body provided by the client. Its value should be set to <b>application/json</b>. <br><br> For more information, refer to <a href=\"/api-docs/static/rest-request-components.html#HTTP\" target=\"_blank \">HTTP request headers</a>. (required)
        :return: ImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'content_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_image_from_url" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_image_from_url`")  # noqa: E501
        # verify the required parameter 'content_type' is set
        if ('content_type' not in params or
                params['content_type'] is None):
            raise ValueError("Missing the required parameter `content_type` when calling `create_image_from_url`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'content_type' in params:
            header_params['Content-Type'] = params['content_type']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_auth']  # noqa: E501

        return self.api_client.call_api(
            '/image/create_image_from_url', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ImageResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_image(self, image_id, **kwargs):  # noqa: E501
        """get_image  # noqa: E501

        This method retrieves an EPS image URL and its expiration details for the unique identifier specified in the path parameter <b>image_id</b>. Use the retrieved EPS image URL to add the image to a listing through the <b>Inventory API</b> or the <b>Trading API</b>. See <a href=\"/api-docs/sell/static/inventory/managing-image-media.html\"  target=\"_blank\">Managing images</a> for additional details.<br><br><span class=\"tablenote\"><b>Note:</b> If a user inputs a valid <b>image_id</b> as a path parameter but the EPS image associated with that ID has expired, the call will fail and a <b>404 Not Found</b> status code will be returned.</span>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_image(image_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str image_id: This path parameter is the unique identifier of a created image. Use the value returned in the location header of the method used to create the image (<b>createImageFromFile</b> or <b>createImageFromUrl</b>, as applicable). (required)
        :return: ImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_image_with_http_info(image_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_image_with_http_info(image_id, **kwargs)  # noqa: E501
            return data

    def get_image_with_http_info(self, image_id, **kwargs):  # noqa: E501
        """get_image  # noqa: E501

        This method retrieves an EPS image URL and its expiration details for the unique identifier specified in the path parameter <b>image_id</b>. Use the retrieved EPS image URL to add the image to a listing through the <b>Inventory API</b> or the <b>Trading API</b>. See <a href=\"/api-docs/sell/static/inventory/managing-image-media.html\"  target=\"_blank\">Managing images</a> for additional details.<br><br><span class=\"tablenote\"><b>Note:</b> If a user inputs a valid <b>image_id</b> as a path parameter but the EPS image associated with that ID has expired, the call will fail and a <b>404 Not Found</b> status code will be returned.</span>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_image_with_http_info(image_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str image_id: This path parameter is the unique identifier of a created image. Use the value returned in the location header of the method used to create the image (<b>createImageFromFile</b> or <b>createImageFromUrl</b>, as applicable). (required)
        :return: ImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['image_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_image" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'image_id' is set
        if ('image_id' not in params or
                params['image_id'] is None):
            raise ValueError("Missing the required parameter `image_id` when calling `get_image`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'image_id' in params:
            path_params['image_id'] = params['image_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_auth']  # noqa: E501

        return self.api_client.call_api(
            '/image/{image_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ImageResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Browse API

    The Browse API has the following resources:<ul><li><b>item_summary:</b><br>Allows shoppers to search for specific items by keyword, GTIN, category, charity, product, image, or item aspects and refine the results by using filters, such as aspects, compatibility, and fields values, or UI parameters.</li><li><b>item:</b><br>Allows shoppers to retrieve the details of a specific item or all items in an item group, which is an item with variations such as color and size and check if a product is compatible with the specified item, such as if a specific car is compatible with a specific part.<br><br>This resource also provides a bridge between the eBay legacy APIs, such as the <a href=\"/api-docs/user-guides/static/finding-user-guide-landing.html\" target=\"_blank\">Finding</b>, and the RESTful APIs, which use different formats for the item IDs.</li></ul>The <b>item_summary</b>, <b>search_by_image</b>, and <b>item</b> resource calls require an <a href=\"/api-docs/static/oauth-client-credentials-grant.html\" target=\"_blank\">Application access token</a>.  # noqa: E501

    OpenAPI spec version: v1.20.2
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CategoryDistribution(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'category_id': 'str',
        'category_name': 'str',
        'match_count': 'int',
        'refinement_href': 'str'
    }

    attribute_map = {
        'category_id': 'categoryId',
        'category_name': 'categoryName',
        'match_count': 'matchCount',
        'refinement_href': 'refinementHref'
    }

    def __init__(self, category_id=None, category_name=None, match_count=None, refinement_href=None):  # noqa: E501
        """CategoryDistribution - a model defined in Swagger"""  # noqa: E501
        self._category_id = None
        self._category_name = None
        self._match_count = None
        self._refinement_href = None
        self.discriminator = None
        if category_id is not None:
            self.category_id = category_id
        if category_name is not None:
            self.category_name = category_name
        if match_count is not None:
            self.match_count = match_count
        if refinement_href is not None:
            self.refinement_href = refinement_href

    @property
    def category_id(self):
        """Gets the category_id of this CategoryDistribution.  # noqa: E501

        The unique identifier of the category.  # noqa: E501

        :return: The category_id of this CategoryDistribution.  # noqa: E501
        :rtype: str
        """
        return self._category_id

    @category_id.setter
    def category_id(self, category_id):
        """Sets the category_id of this CategoryDistribution.

        The unique identifier of the category.  # noqa: E501

        :param category_id: The category_id of this CategoryDistribution.  # noqa: E501
        :type: str
        """

        self._category_id = category_id

    @property
    def category_name(self):
        """Gets the category_name of this CategoryDistribution.  # noqa: E501

        The name of the category, such as <b>Baby &amp; Toddler Clothing</b>.  # noqa: E501

        :return: The category_name of this CategoryDistribution.  # noqa: E501
        :rtype: str
        """
        return self._category_name

    @category_name.setter
    def category_name(self, category_name):
        """Sets the category_name of this CategoryDistribution.

        The name of the category, such as <b>Baby &amp; Toddler Clothing</b>.  # noqa: E501

        :param category_name: The category_name of this CategoryDistribution.  # noqa: E501
        :type: str
        """

        self._category_name = category_name

    @property
    def match_count(self):
        """Gets the match_count of this CategoryDistribution.  # noqa: E501

        The number of items in this category.  # noqa: E501

        :return: The match_count of this CategoryDistribution.  # noqa: E501
        :rtype: int
        """
        return self._match_count

    @match_count.setter
    def match_count(self, match_count):
        """Sets the match_count of this CategoryDistribution.

        The number of items in this category.  # noqa: E501

        :param match_count: The match_count of this CategoryDistribution.  # noqa: E501
        :type: int
        """

        self._match_count = match_count

    @property
    def refinement_href(self):
        """Gets the refinement_href of this CategoryDistribution.  # noqa: E501

        The HATEOAS reference of this category.  # noqa: E501

        :return: The refinement_href of this CategoryDistribution.  # noqa: E501
        :rtype: str
        """
        return self._refinement_href

    @refinement_href.setter
    def refinement_href(self, refinement_href):
        """Sets the refinement_href of this CategoryDistribution.

        The HATEOAS reference of this category.  # noqa: E501

        :param refinement_href: The refinement_href of this CategoryDistribution.  # noqa: E501
        :type: str
        """

        self._refinement_href = refinement_href

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CategoryDistribution, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CategoryDistribution):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    EDIS public shipping API

    <div class=\"msgbox_important\"><p class=\"msgbox_importantInDiv\" data-mc-autonum=\"&lt;b&gt;&lt;span style=&quot;color: #dd1e31;&quot; class=&quot;mcFormatColor&quot;&gt;Important! &lt;/span&gt;&lt;/b&gt;\"><span class=\"autonumber\"><span><b><span style=\"color: #dd1e31;\" class=\"mcFormatColor\">Important!</span></b></span></span> This method is only available for Greater-China based sellers with an active eDIS account.</p></div><br>This API allows 3rd party developers in the Greater-China area to process package shipping details.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GetServiceListResponsesData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'href': 'str',
        'limit': 'int',
        'next': 'str',
        'offset': 'int',
        'prev': 'str',
        'services': 'list[ServiceInfoResponses]',
        'total': 'int'
    }

    attribute_map = {
        'href': 'href',
        'limit': 'limit',
        'next': 'next',
        'offset': 'offset',
        'prev': 'prev',
        'services': 'services',
        'total': 'total'
    }

    def __init__(self, href=None, limit=None, next=None, offset=None, prev=None, services=None, total=None):  # noqa: E501
        """GetServiceListResponsesData - a model defined in Swagger"""  # noqa: E501
        self._href = None
        self._limit = None
        self._next = None
        self._offset = None
        self._prev = None
        self._services = None
        self._total = None
        self.discriminator = None
        if href is not None:
            self.href = href
        if limit is not None:
            self.limit = limit
        if next is not None:
            self.next = next
        if offset is not None:
            self.offset = offset
        if prev is not None:
            self.prev = prev
        if services is not None:
            self.services = services
        if total is not None:
            self.total = total

    @property
    def href(self):
        """Gets the href of this GetServiceListResponsesData.  # noqa: E501

        The URL to the current page of the result set.  # noqa: E501

        :return: The href of this GetServiceListResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this GetServiceListResponsesData.

        The URL to the current page of the result set.  # noqa: E501

        :param href: The href of this GetServiceListResponsesData.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def limit(self):
        """Gets the limit of this GetServiceListResponsesData.  # noqa: E501

        The value of the <b>limit</b> parameter submitted in the request.  # noqa: E501

        :return: The limit of this GetServiceListResponsesData.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this GetServiceListResponsesData.

        The value of the <b>limit</b> parameter submitted in the request.  # noqa: E501

        :param limit: The limit of this GetServiceListResponsesData.  # noqa: E501
        :type: int
        """

        self._limit = limit

    @property
    def next(self):
        """Gets the next of this GetServiceListResponsesData.  # noqa: E501

        The URI for the next page of results. This value is returned if there is an additional page of results to return from the result set.  # noqa: E501

        :return: The next of this GetServiceListResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._next

    @next.setter
    def next(self, next):
        """Sets the next of this GetServiceListResponsesData.

        The URI for the next page of results. This value is returned if there is an additional page of results to return from the result set.  # noqa: E501

        :param next: The next of this GetServiceListResponsesData.  # noqa: E501
        :type: str
        """

        self._next = next

    @property
    def offset(self):
        """Gets the offset of this GetServiceListResponsesData.  # noqa: E501

        The value of the <b>offset</b> parameter submitted in the request.  # noqa: E501

        :return: The offset of this GetServiceListResponsesData.  # noqa: E501
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this GetServiceListResponsesData.

        The value of the <b>offset</b> parameter submitted in the request.  # noqa: E501

        :param offset: The offset of this GetServiceListResponsesData.  # noqa: E501
        :type: int
        """

        self._offset = offset

    @property
    def prev(self):
        """Gets the prev of this GetServiceListResponsesData.  # noqa: E501

        The URI for the previous page of results. This is returned if there is a previous page of results from the result set.  # noqa: E501

        :return: The prev of this GetServiceListResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._prev

    @prev.setter
    def prev(self, prev):
        """Sets the prev of this GetServiceListResponsesData.

        The URI for the previous page of results. This is returned if there is a previous page of results from the result set.  # noqa: E501

        :param prev: The prev of this GetServiceListResponsesData.  # noqa: E501
        :type: str
        """

        self._prev = prev

    @property
    def services(self):
        """Gets the services of this GetServiceListResponsesData.  # noqa: E501

        This array returns a list of available shipping services, as well as the descriptions, directions, and identifiers of each service.  # noqa: E501

        :return: The services of this GetServiceListResponsesData.  # noqa: E501
        :rtype: list[ServiceInfoResponses]
        """
        return self._services

    @services.setter
    def services(self, services):
        """Sets the services of this GetServiceListResponsesData.

        This array returns a list of available shipping services, as well as the descriptions, directions, and identifiers of each service.  # noqa: E501

        :param services: The services of this GetServiceListResponsesData.  # noqa: E501
        :type: list[ServiceInfoResponses]
        """

        self._services = services

    @property
    def total(self):
        """Gets the total of this GetServiceListResponsesData.  # noqa: E501

        The total number of shipping services being displayed on the current results page.  # noqa: E501

        :return: The total of this GetServiceListResponsesData.  # noqa: E501
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this GetServiceListResponsesData.

        The total number of shipping services being displayed on the current results page.  # noqa: E501

        :param total: The total of this GetServiceListResponsesData.  # noqa: E501
        :type: int
        """

        self._total = total

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetServiceListResponsesData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetServiceListResponsesData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Account v2 API

    This API allows sellers to retrieve and manage their custom shipping rate tables. In addition, this API also provides sellers in mainland China methods to configure split-payouts between two separate payment instruments.  # noqa: E501

    OpenAPI spec version: 2.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UpdatePayoutPercentage(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'instrument_id': 'str',
        'payout_percentage': 'str'
    }

    attribute_map = {
        'instrument_id': 'instrumentId',
        'payout_percentage': 'payoutPercentage'
    }

    def __init__(self, instrument_id=None, payout_percentage=None):  # noqa: E501
        """UpdatePayoutPercentage - a model defined in Swagger"""  # noqa: E501
        self._instrument_id = None
        self._payout_percentage = None
        self.discriminator = None
        if instrument_id is not None:
            self.instrument_id = instrument_id
        if payout_percentage is not None:
            self.payout_percentage = payout_percentage

    @property
    def instrument_id(self):
        """Gets the instrument_id of this UpdatePayoutPercentage.  # noqa: E501

        The unique reference identifier for a payout instrument. This value is returned in the <a href=\"/api-docs/sell/account/v2/resources/payout_settings/methods/getPayoutSettings\" target=\"_blank \">getPayoutSettings</a> response and is needed to change split-payout percentages through an <b>updatePayoutPercentage</b> request.  # noqa: E501

        :return: The instrument_id of this UpdatePayoutPercentage.  # noqa: E501
        :rtype: str
        """
        return self._instrument_id

    @instrument_id.setter
    def instrument_id(self, instrument_id):
        """Sets the instrument_id of this UpdatePayoutPercentage.

        The unique reference identifier for a payout instrument. This value is returned in the <a href=\"/api-docs/sell/account/v2/resources/payout_settings/methods/getPayoutSettings\" target=\"_blank \">getPayoutSettings</a> response and is needed to change split-payout percentages through an <b>updatePayoutPercentage</b> request.  # noqa: E501

        :param instrument_id: The instrument_id of this UpdatePayoutPercentage.  # noqa: E501
        :type: str
        """

        self._instrument_id = instrument_id

    @property
    def payout_percentage(self):
        """Gets the payout_percentage of this UpdatePayoutPercentage.  # noqa: E501

        The user-defined payout percentage allocated to this instrument. For example, <code>50</code> indicates that 50% of the payout goes to this instrument.<br/><br/>The split-payout percentage <b>must</b> be a positive integer value from 0-100. The values of two instruments <b>must</b> always add up to 100%. If the values do not equal 100, the call will fail.  # noqa: E501

        :return: The payout_percentage of this UpdatePayoutPercentage.  # noqa: E501
        :rtype: str
        """
        return self._payout_percentage

    @payout_percentage.setter
    def payout_percentage(self, payout_percentage):
        """Sets the payout_percentage of this UpdatePayoutPercentage.

        The user-defined payout percentage allocated to this instrument. For example, <code>50</code> indicates that 50% of the payout goes to this instrument.<br/><br/>The split-payout percentage <b>must</b> be a positive integer value from 0-100. The values of two instruments <b>must</b> always add up to 100%. If the values do not equal 100, the call will fail.  # noqa: E501

        :param payout_percentage: The payout_percentage of this UpdatePayoutPercentage.  # noqa: E501
        :type: str
        """

        self._payout_percentage = payout_percentage

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdatePayoutPercentage, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdatePayoutPercentage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Vero Public API's

    The VeRO API has methods that allow owners of an intellectual property to report eBay listings that infringe on their intellectual property rights. It contains methods to report a listing, retrieve supported VeRO reason codes, and retrieve the status of submitted and items.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ReportedItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'item_id': 'str',
        'reason_for_failure': 'str',
        'status': 'str'
    }

    attribute_map = {
        'item_id': 'itemId',
        'reason_for_failure': 'reasonForFailure',
        'status': 'status'
    }

    def __init__(self, item_id=None, reason_for_failure=None, status=None):  # noqa: E501
        """ReportedItem - a model defined in Swagger"""  # noqa: E501
        self._item_id = None
        self._reason_for_failure = None
        self._status = None
        self.discriminator = None
        if item_id is not None:
            self.item_id = item_id
        if reason_for_failure is not None:
            self.reason_for_failure = reason_for_failure
        if status is not None:
            self.status = status

    @property
    def item_id(self):
        """Gets the item_id of this ReportedItem.  # noqa: E501

        The unique identifier of the listing that is being reported for copyright, trademark, or intellectual right infringement.  # noqa: E501

        :return: The item_id of this ReportedItem.  # noqa: E501
        :rtype: str
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this ReportedItem.

        The unique identifier of the listing that is being reported for copyright, trademark, or intellectual right infringement.  # noqa: E501

        :param item_id: The item_id of this ReportedItem.  # noqa: E501
        :type: str
        """

        self._item_id = item_id

    @property
    def reason_for_failure(self):
        """Gets the reason_for_failure of this ReportedItem.  # noqa: E501

        This text explanation is submitted by eBay when the submission of a VeRO Report has failed or was blocked.<br><br>This field is conditionally returned if the <b>status</b> value of the report is <code>ClarificationRequired</code> or <code>SubmissionFailed</code>.  # noqa: E501

        :return: The reason_for_failure of this ReportedItem.  # noqa: E501
        :rtype: str
        """
        return self._reason_for_failure

    @reason_for_failure.setter
    def reason_for_failure(self, reason_for_failure):
        """Sets the reason_for_failure of this ReportedItem.

        This text explanation is submitted by eBay when the submission of a VeRO Report has failed or was blocked.<br><br>This field is conditionally returned if the <b>status</b> value of the report is <code>ClarificationRequired</code> or <code>SubmissionFailed</code>.  # noqa: E501

        :param reason_for_failure: The reason_for_failure of this ReportedItem.  # noqa: E501
        :type: str
        """

        self._reason_for_failure = reason_for_failure

    @property
    def status(self):
        """Gets the status of this ReportedItem.  # noqa: E501

        The current status of the VeRO reported item. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/commerce/vero/types/VeroReportedItemStatusEnum'>eBay API documentation</a>  # noqa: E501

        :return: The status of this ReportedItem.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ReportedItem.

        The current status of the VeRO reported item. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/commerce/vero/types/VeroReportedItemStatusEnum'>eBay API documentation</a>  # noqa: E501

        :param status: The status of this ReportedItem.  # noqa: E501
        :type: str
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ReportedItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReportedItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Deal API

    <span class=\"tablenote\"><b>Note:</b> This is a <a href=\"https://developer.ebay.com/api-docs/static/versioning.html#limited\" target=\"_blank\"> <img src=\"/cms/img/docs/partners-api.svg\" class=\"legend-icon partners-icon\" title=\"Limited Release\"  alt=\"Limited Release\" />(Limited Release)</a> API available only to select developers approved by business units. For information on how to obtain access to this API in production, see the <a href=\"/../api-docs/buy/static/buy-requirements.html\" target=\"_blank\">Buy APIs Requirements</a>.</span><br /><br />This API allows third-party developers to search for and retrieve details about eBay deals and events, as well as the items associated with those deals and events.  # noqa: E501

    OpenAPI spec version: v1.3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Terms(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'full_text': 'str',
        'summary': 'str'
    }

    attribute_map = {
        'full_text': 'fullText',
        'summary': 'summary'
    }

    def __init__(self, full_text=None, summary=None):  # noqa: E501
        """Terms - a model defined in Swagger"""  # noqa: E501
        self._full_text = None
        self._summary = None
        self.discriminator = None
        if full_text is not None:
            self.full_text = full_text
        if summary is not None:
            self.summary = summary

    @property
    def full_text(self):
        """Gets the full_text of this Terms.  # noqa: E501

        A full-text description of the terms.  # noqa: E501

        :return: The full_text of this Terms.  # noqa: E501
        :rtype: str
        """
        return self._full_text

    @full_text.setter
    def full_text(self, full_text):
        """Sets the full_text of this Terms.

        A full-text description of the terms.  # noqa: E501

        :param full_text: The full_text of this Terms.  # noqa: E501
        :type: str
        """

        self._full_text = full_text

    @property
    def summary(self):
        """Gets the summary of this Terms.  # noqa: E501

        A summarized description of the terms.  # noqa: E501

        :return: The summary of this Terms.  # noqa: E501
        :rtype: str
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """Sets the summary of this Terms.

        A summarized description of the terms.  # noqa: E501

        :param summary: The summary of this Terms.  # noqa: E501
        :type: str
        """

        self._summary = summary

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Terms, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Terms):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Browse API

    The Browse API has the following resources:<ul><li><b>item_summary:</b><br>Allows shoppers to search for specific items by keyword, GTIN, category, charity, product, image, or item aspects and refine the results by using filters, such as aspects, compatibility, and fields values, or UI parameters.</li><li><b>item:</b><br>Allows shoppers to retrieve the details of a specific item or all items in an item group, which is an item with variations such as color and size and check if a product is compatible with the specified item, such as if a specific car is compatible with a specific part.<br><br>This resource also provides a bridge between the eBay legacy APIs, such as the <a href=\"/api-docs/user-guides/static/finding-user-guide-landing.html\" target=\"_blank\">Finding</b>, and the RESTful APIs, which use different formats for the item IDs.</li></ul>The <b>item_summary</b>, <b>search_by_image</b>, and <b>item</b> resource calls require an <a href=\"/api-docs/static/oauth-client-credentials-grant.html\" target=\"_blank\">Application access token</a>.  # noqa: E501

    OpenAPI spec version: v1.20.2
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AdditionalProductIdentity(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'product_identity': 'list[ProductIdentity]'
    }

    attribute_map = {
        'product_identity': 'productIdentity'
    }

    def __init__(self, product_identity=None):  # noqa: E501
        """AdditionalProductIdentity - a model defined in Swagger"""  # noqa: E501
        self._product_identity = None
        self.discriminator = None
        if product_identity is not None:
            self.product_identity = product_identity

    @property
    def product_identity(self):
        """Gets the product_identity of this AdditionalProductIdentity.  # noqa: E501

        An array of product identifier/value pairs for the product associated with the item. This is returned if the seller has associated the eBay Product Identifier (ePID) with the item and the request has <code>fieldgroups</code> set to <code>PRODUCT</code>.<br><br>The following table shows what is returned, based on the item information provided by the seller, when <code>fieldgroups</code> is set to <code>PRODUCT</code>.<br><br><div style=\"overflow-x:auto;\"><table border=1><tr><th>ePID Provided</th><th>Product ID(s) Provided</th><th>Response</th></tr><tr><td>No</td><td>No</td><td>The <code>AdditionalProductIdentity</code> container is <i>not</i> returned.</td></tr><tr><td>No</td><td>Yes</td><td>The <code>AdditionalProductIdentity</code> container is <i>not</i> returned but the product identifiers specified by the seller are returned in the <code>localizedAspects</code> container.</td></tr><tr><td>Yes</td><td>No</td><td>The <code>AdditionalProductIdentity</code> container is returned listing the product identifiers of the product.</td></tr><tr><td>Yes</td><td>Yes</td><td>The <code>AdditionalProductIdentity</code> container is returned listing all the product identifiers of the product and the product identifiers specified by the seller are returned in the <code>localizedAspects</code> container.</td></tr></table></div>  # noqa: E501

        :return: The product_identity of this AdditionalProductIdentity.  # noqa: E501
        :rtype: list[ProductIdentity]
        """
        return self._product_identity

    @product_identity.setter
    def product_identity(self, product_identity):
        """Sets the product_identity of this AdditionalProductIdentity.

        An array of product identifier/value pairs for the product associated with the item. This is returned if the seller has associated the eBay Product Identifier (ePID) with the item and the request has <code>fieldgroups</code> set to <code>PRODUCT</code>.<br><br>The following table shows what is returned, based on the item information provided by the seller, when <code>fieldgroups</code> is set to <code>PRODUCT</code>.<br><br><div style=\"overflow-x:auto;\"><table border=1><tr><th>ePID Provided</th><th>Product ID(s) Provided</th><th>Response</th></tr><tr><td>No</td><td>No</td><td>The <code>AdditionalProductIdentity</code> container is <i>not</i> returned.</td></tr><tr><td>No</td><td>Yes</td><td>The <code>AdditionalProductIdentity</code> container is <i>not</i> returned but the product identifiers specified by the seller are returned in the <code>localizedAspects</code> container.</td></tr><tr><td>Yes</td><td>No</td><td>The <code>AdditionalProductIdentity</code> container is returned listing the product identifiers of the product.</td></tr><tr><td>Yes</td><td>Yes</td><td>The <code>AdditionalProductIdentity</code> container is returned listing all the product identifiers of the product and the product identifiers specified by the seller are returned in the <code>localizedAspects</code> container.</td></tr></table></div>  # noqa: E501

        :param product_identity: The product_identity of this AdditionalProductIdentity.  # noqa: E501
        :type: list[ProductIdentity]
        """

        self._product_identity = product_identity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AdditionalProductIdentity, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdditionalProductIdentity):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Marketing API

    <p>The <i>Marketing API </i> offers two platforms that sellers can use to promote and advertise their products:</p> <ul><li><b>Promoted Listings</b> is an eBay ad service that lets sellers set up <i>ad campaigns </i> for the products they want to promote. eBay displays the ads in search results and in other marketing modules as <b>SPONSORED</b> listings. If an item in a Promoted Listings campaign sells, the seller is assessed a Promoted Listings fee, which is a seller-specified percentage applied to the sales price. For complete details, refer to the <a href=\"/api-docs/sell/static/marketing/pl-landing.html\">Promoted Listings playbook</a>.</li><li><b>Promotions Manager</b> gives sellers a way to offer discounts on specific items as a way to attract buyers to their inventory. Sellers can set up discounts (such as \"20% off\" and other types of offers) on specific items or on an entire customer order. To further attract buyers, eBay prominently displays promotion <i>teasers</i> throughout buyer flows. For complete details, see <a href=\"/api-docs/sell/static/marketing/promotions-manager.html\">Promotions Manager</a>.</li></ul>  <p><b>Marketing reports</b>, on both the Promoted Listings and Promotions Manager platforms, give sellers information that shows the effectiveness of their marketing strategies. The data gives sellers the ability to review and fine tune their marketing efforts.</p><p><b>Store Email Campaign</b> allows sellers to create and send email campaigns to customers who have signed up to receive their newsletter. For more information on email campaigns, see <a href=\"/api-docs/sell/static/marketing/store-email-campaigns.html#email-campain-types\" target=\"_blank\">Store Email Campaigns</a>.<p class=\"tablenote\"><b>Important!</b> Sellers must have an active eBay Store subscription, and they must accept the <b>Terms and Conditions</b> before they can make requests to these APIs in the Production environment. There are also site-specific listings requirements and restrictions associated with these marketing tools, as listed in the \"requirements and restrictions\" sections for <a href=\"/api-docs/sell/marketing/static/overview.html#PL-requirements\">Promoted Listings</a> and <a href=\"/api-docs/sell/marketing/static/overview.html#PM-requirements\">Promotions Manager</a>.</p> <p>The table below lists all the Marketing API calls grouped by resource.</p>  # noqa: E501

    OpenAPI spec version: v1.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ReportMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dimension_metadata': 'list[DimensionMetadata]',
        'max_number_of_dimensions_to_request': 'int',
        'max_number_of_metrics_to_request': 'int',
        'channel': 'str',
        'metric_metadata': 'list[MetricMetadata]',
        'report_type': 'str'
    }

    attribute_map = {
        'dimension_metadata': 'dimensionMetadata',
        'max_number_of_dimensions_to_request': 'maxNumberOfDimensionsToRequest',
        'max_number_of_metrics_to_request': 'maxNumberOfMetricsToRequest',
        'channel': 'channel',
        'metric_metadata': 'metricMetadata',
        'report_type': 'reportType'
    }

    def __init__(self, dimension_metadata=None, max_number_of_dimensions_to_request=None, max_number_of_metrics_to_request=None, channel=None, metric_metadata=None, report_type=None):  # noqa: E501
        """ReportMetadata - a model defined in Swagger"""  # noqa: E501
        self._dimension_metadata = None
        self._max_number_of_dimensions_to_request = None
        self._max_number_of_metrics_to_request = None
        self._channel = None
        self._metric_metadata = None
        self._report_type = None
        self.discriminator = None
        if dimension_metadata is not None:
            self.dimension_metadata = dimension_metadata
        if max_number_of_dimensions_to_request is not None:
            self.max_number_of_dimensions_to_request = max_number_of_dimensions_to_request
        if max_number_of_metrics_to_request is not None:
            self.max_number_of_metrics_to_request = max_number_of_metrics_to_request
        if channel is not None:
            self.channel = channel
        if metric_metadata is not None:
            self.metric_metadata = metric_metadata
        if report_type is not None:
            self.report_type = report_type

    @property
    def dimension_metadata(self):
        """Gets the dimension_metadata of this ReportMetadata.  # noqa: E501

        A list containing the metadata for the dimension used in the report.  # noqa: E501

        :return: The dimension_metadata of this ReportMetadata.  # noqa: E501
        :rtype: list[DimensionMetadata]
        """
        return self._dimension_metadata

    @dimension_metadata.setter
    def dimension_metadata(self, dimension_metadata):
        """Sets the dimension_metadata of this ReportMetadata.

        A list containing the metadata for the dimension used in the report.  # noqa: E501

        :param dimension_metadata: The dimension_metadata of this ReportMetadata.  # noqa: E501
        :type: list[DimensionMetadata]
        """

        self._dimension_metadata = dimension_metadata

    @property
    def max_number_of_dimensions_to_request(self):
        """Gets the max_number_of_dimensions_to_request of this ReportMetadata.  # noqa: E501

        The maximum number of dimensions that can be requested for the specified report type.  # noqa: E501

        :return: The max_number_of_dimensions_to_request of this ReportMetadata.  # noqa: E501
        :rtype: int
        """
        return self._max_number_of_dimensions_to_request

    @max_number_of_dimensions_to_request.setter
    def max_number_of_dimensions_to_request(self, max_number_of_dimensions_to_request):
        """Sets the max_number_of_dimensions_to_request of this ReportMetadata.

        The maximum number of dimensions that can be requested for the specified report type.  # noqa: E501

        :param max_number_of_dimensions_to_request: The max_number_of_dimensions_to_request of this ReportMetadata.  # noqa: E501
        :type: int
        """

        self._max_number_of_dimensions_to_request = max_number_of_dimensions_to_request

    @property
    def max_number_of_metrics_to_request(self):
        """Gets the max_number_of_metrics_to_request of this ReportMetadata.  # noqa: E501

        The maximum number of metrics that can be requested for the specified report type.  # noqa: E501

        :return: The max_number_of_metrics_to_request of this ReportMetadata.  # noqa: E501
        :rtype: int
        """
        return self._max_number_of_metrics_to_request

    @max_number_of_metrics_to_request.setter
    def max_number_of_metrics_to_request(self, max_number_of_metrics_to_request):
        """Sets the max_number_of_metrics_to_request of this ReportMetadata.

        The maximum number of metrics that can be requested for the specified report type.  # noqa: E501

        :param max_number_of_metrics_to_request: The max_number_of_metrics_to_request of this ReportMetadata.  # noqa: E501
        :type: int
        """

        self._max_number_of_metrics_to_request = max_number_of_metrics_to_request

    @property
    def channel(self):
        """Gets the channel of this ReportMetadata.  # noqa: E501

        This field indicates whether a COST_PER_CLICK report type is related to an ON_SITE or OFF_SITE Promoted Listings campaign. This field is not returned for COST_PER_SALE report types since COST_PER_SALE campaigns are only available ON_SITE. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/marketing/types/pls:ChannelEnum'>eBay API documentation</a>  # noqa: E501

        :return: The channel of this ReportMetadata.  # noqa: E501
        :rtype: str
        """
        return self._channel

    @channel.setter
    def channel(self, channel):
        """Sets the channel of this ReportMetadata.

        This field indicates whether a COST_PER_CLICK report type is related to an ON_SITE or OFF_SITE Promoted Listings campaign. This field is not returned for COST_PER_SALE report types since COST_PER_SALE campaigns are only available ON_SITE. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/marketing/types/pls:ChannelEnum'>eBay API documentation</a>  # noqa: E501

        :param channel: The channel of this ReportMetadata.  # noqa: E501
        :type: str
        """

        self._channel = channel

    @property
    def metric_metadata(self):
        """Gets the metric_metadata of this ReportMetadata.  # noqa: E501

        A list containing the metadata for the metrics in the report.  # noqa: E501

        :return: The metric_metadata of this ReportMetadata.  # noqa: E501
        :rtype: list[MetricMetadata]
        """
        return self._metric_metadata

    @metric_metadata.setter
    def metric_metadata(self, metric_metadata):
        """Sets the metric_metadata of this ReportMetadata.

        A list containing the metadata for the metrics in the report.  # noqa: E501

        :param metric_metadata: The metric_metadata of this ReportMetadata.  # noqa: E501
        :type: list[MetricMetadata]
        """

        self._metric_metadata = metric_metadata

    @property
    def report_type(self):
        """Gets the report_type of this ReportMetadata.  # noqa: E501

        The <b>report_type</b>, as specified in the request to create the report task.<br/><br/><span class=\"tablenote\"><b>Note:</b> INVENTORY_PERFORMANCE_REPORT is not currently available; availability date is pending.</span> For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/marketing/types/plr:ReportTypeEnum'>eBay API documentation</a>  # noqa: E501

        :return: The report_type of this ReportMetadata.  # noqa: E501
        :rtype: str
        """
        return self._report_type

    @report_type.setter
    def report_type(self, report_type):
        """Sets the report_type of this ReportMetadata.

        The <b>report_type</b>, as specified in the request to create the report task.<br/><br/><span class=\"tablenote\"><b>Note:</b> INVENTORY_PERFORMANCE_REPORT is not currently available; availability date is pending.</span> For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/marketing/types/plr:ReportTypeEnum'>eBay API documentation</a>  # noqa: E501

        :param report_type: The report_type of this ReportMetadata.  # noqa: E501
        :type: str
        """

        self._report_type = report_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ReportMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReportMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    EDIS public shipping API

    <div class=\"msgbox_important\"><p class=\"msgbox_importantInDiv\" data-mc-autonum=\"&lt;b&gt;&lt;span style=&quot;color: #dd1e31;&quot; class=&quot;mcFormatColor&quot;&gt;Important! &lt;/span&gt;&lt;/b&gt;\"><span class=\"autonumber\"><span><b><span style=\"color: #dd1e31;\" class=\"mcFormatColor\">Important!</span></b></span></span> This method is only available for Greater-China based sellers with an active eDIS account.</p></div><br>This API allows 3rd party developers in the Greater-China area to process package shipping details.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GetItemPackageIdResponsesData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'package_id': 'str',
        'package_status': 'str',
        'tracking_number': 'str'
    }

    attribute_map = {
        'package_id': 'packageId',
        'package_status': 'packageStatus',
        'tracking_number': 'trackingNumber'
    }

    def __init__(self, package_id=None, package_status=None, tracking_number=None):  # noqa: E501
        """GetItemPackageIdResponsesData - a model defined in Swagger"""  # noqa: E501
        self._package_id = None
        self._package_status = None
        self._tracking_number = None
        self.discriminator = None
        if package_id is not None:
            self.package_id = package_id
        if package_status is not None:
            self.package_status = package_status
        if tracking_number is not None:
            self.tracking_number = tracking_number

    @property
    def package_id(self):
        """Gets the package_id of this GetItemPackageIdResponsesData.  # noqa: E501

        The unique identifier of the package.  # noqa: E501

        :return: The package_id of this GetItemPackageIdResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._package_id

    @package_id.setter
    def package_id(self, package_id):
        """Sets the package_id of this GetItemPackageIdResponsesData.

        The unique identifier of the package.  # noqa: E501

        :param package_id: The package_id of this GetItemPackageIdResponsesData.  # noqa: E501
        :type: str
        """

        self._package_id = package_id

    @property
    def package_status(self):
        """Gets the package_status of this GetItemPackageIdResponsesData.  # noqa: E501

        The current status of the package. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/edelivery_international_shipping/types/api:PackageStatusEnum'>eBay API documentation</a>  # noqa: E501

        :return: The package_status of this GetItemPackageIdResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._package_status

    @package_status.setter
    def package_status(self, package_status):
        """Sets the package_status of this GetItemPackageIdResponsesData.

        The current status of the package. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/edelivery_international_shipping/types/api:PackageStatusEnum'>eBay API documentation</a>  # noqa: E501

        :param package_status: The package_status of this GetItemPackageIdResponsesData.  # noqa: E501
        :type: str
        """

        self._package_status = package_status

    @property
    def tracking_number(self):
        """Gets the tracking_number of this GetItemPackageIdResponsesData.  # noqa: E501

        The tracking number of the package.  # noqa: E501

        :return: The tracking_number of this GetItemPackageIdResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._tracking_number

    @tracking_number.setter
    def tracking_number(self, tracking_number):
        """Sets the tracking_number of this GetItemPackageIdResponsesData.

        The tracking number of the package.  # noqa: E501

        :param tracking_number: The tracking_number of this GetItemPackageIdResponsesData.  # noqa: E501
        :type: str
        """

        self._tracking_number = tracking_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetItemPackageIdResponsesData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetItemPackageIdResponsesData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
